Structure FMOD_DSP
  userdata.l     ; '[in]'[out] User created data the dsp plugin writer wants to attach to this object. 
EndStructure
Structure FMOD_DSP_PARAMETERDESC
  min.f                                 ; [in] Minimum value of the parameter (ie 100.0). 
  max.f                                 ; [in] Maximum value of the parameter (ie 22050.0). 
  defaultval.f                          ; [in] Default value of parameter. 
  name.s                                ; [in] Name of the parameter to be displayed (ie "Cutoff frequency"). 
  label.s                               ; [in] Short string to be put next to value to denote the unit type (ie "hz"). 
  description.s                         ; [in] Description of the parameter to be displayed as a help item / tooltip for this parameter. 
EndStructure
Global fmodLib.l

Procedure Init_FMOD()
 ; fmodLib = OpenLibrary(#PB_Any, "fmodex.dll")
 ; ProcedureReturn IsLibrary(fmodLib)
EndProcedure

#FMOD_VERSION  = $40606

Enumeration ; FMOD_INITFLAGS
  #FMOD_INIT_NORMAL = $0                           ; All platforms - Initialize normally.
  #FMOD_INIT_STREAM_FROM_UPDATE = $1               ; All platforms - No stream thread is created internally.  Streams are driven from System::update.  Mainly used with non-realtime outputs. 
  #FMOD_INIT_3D_RIGHTHANDED = $2                   ; All platforms - FMOD will treat +X as left, +Y as up and +Z as forwards.
  #FMOD_INIT_DISABLESOFTWARE = $4                  ; All platforms - Disable software mixer to save memory.  Anything created with #FMOD_SOFTWARE will fail and DSP will not work.
  #FMOD_INIT_DSOUND_HRTFNONE = $200                ; Win32 only - for DirectSound output - #FMOD_HARDWARE | #FMOD_3D buffers use simple stereo panning/doppler/attenuation when 3D hardware acceleration is not present.
  #FMOD_INIT_DSOUND_HRTFLIGHT = $400               ; Win32 only - for DirectSound output - #FMOD_HARDWARE | #FMOD_3D buffers use a slightly higher quality algorithm when 3D hardware acceleration is not present.
  #FMOD_INIT_DSOUND_HRTFFULL = $800                ; Win32 only - for DirectSound output - #FMOD_HARDWARE | #FMOD_3D buffers use full quality 3D playback when 3d hardware acceleration is not present.
  #FMOD_INIT_PS2_DISABLECORE0REVERB = $10000       ; PS2 only - Disable reverb on CORE 0 to regain SRAM.
  #FMOD_INIT_PS2_DISABLECORE1REVERB = $20000       ; PS2 only - Disable reverb on CORE 1 to regain SRAM.
  #FMOD_INIT_XBOX_REMOVEHEADROOM = $100000         ; XBox only - By default DirectSound attenuates all sound by 6db to avoid clipping/distortion.  CAUTION.  If you use this flag you are responsible for the final mix to make sure clipping / distortion doesn't happen.
EndEnumeration

Enumeration ; FMOD_DSP_FFT_WINDOW
  #FMOD_DSP_FFT_WINDOW_RECT            ; w[n] = 1.0                                                                                            
  #FMOD_DSP_FFT_WINDOW_TRIANGLE        ; w[n] = TRI(2n/N)                                                                                      
  #FMOD_DSP_FFT_WINDOW_HAMMING         ; w[n] = 0.54 - (0.46 * COS(n/N) )                                                                      
  #FMOD_DSP_FFT_WINDOW_HANNING         ; w[n] = 0.5 *  (1.0  - COS(n/N) )                                                                      
  #FMOD_DSP_FFT_WINDOW_BLACKMAN        ; w[n] = 0.42 - (0.5  * COS(n/N) ) + (0.08 * COS(2.0 * n/N) )                                           
  #FMOD_DSP_FFT_WINDOW_BLACKMANHARRIS  ; w[n] = 0.35875 - (0.48829 * COS(1.0 * n/N)) + (0.14128 * COS(2.0 * n/N)) - (0.01168 * COS(3.0 * n/N)) 
  #FMOD_DSP_FFT_WINDOW_MAX
EndEnumeration

Enumeration ; FMOD_SOUND_TYPE
  #FMOD_SOUND_TYPE_UNKNOWN         ; 3rd party / unknown plugin format.
  #FMOD_SOUND_TYPE_AAC             ; AAC.  Currently unsupported.
  #FMOD_SOUND_TYPE_AIFF            ; AIFF.
  #FMOD_SOUND_TYPE_ASF             ; Microsoft Advanced Systems Format (ie WMA/ASF/WMV).
  #FMOD_SOUND_TYPE_AT3             ; Sony ATRAC 3 format
  #FMOD_SOUND_TYPE_CDDA            ; Digital CD audio.
  #FMOD_SOUND_TYPE_DLS             ; Sound font / downloadable sound bank.
  #FMOD_SOUND_TYPE_FLAC            ; FLAC lossless codec.
  #FMOD_SOUND_TYPE_FSB             ; FMOD Sample Bank.
  #FMOD_SOUND_TYPE_GCADPCM         ; GameCube ADPCM
  #FMOD_SOUND_TYPE_IT              ; Impulse Tracker.
  #FMOD_SOUND_TYPE_MIDI            ; MIDI.
  #FMOD_SOUND_TYPE_MOD             ; Protracker / Fasttracker MOD.
  #FMOD_SOUND_TYPE_MPEG            ; MP2/MP3 MPEG.
  #FMOD_SOUND_TYPE_OGGVORBIS       ; Ogg vorbis.
  #FMOD_SOUND_TYPE_PLAYLIST        ; Information only from ASX/PLS/M3U/WAX playlists
  #FMOD_SOUND_TYPE_RAW             ; Raw PCM data.
  #FMOD_SOUND_TYPE_S3M             ; ScreamTracker 3.
  #FMOD_SOUND_TYPE_SF2             ; Sound font 2 format.
  #FMOD_SOUND_TYPE_USER            ; User created sound.
  #FMOD_SOUND_TYPE_WAV             ; Microsoft WAV.
  #FMOD_SOUND_TYPE_XM              ; FastTracker 2 XM.
  #FMOD_SOUND_TYPE_XMA             ; Xbox360 XMA
  #FMOD_SOUND_TYPE_VAG             ; PlayStation 2 / PlayStation Portable adpcm VAG format.
EndEnumeration

Enumeration ; FMOD_MODE
  #FMOD_DEFAULT = $0                       ; #FMOD_DEFAULT is a default sound type.  Equivalent to all the defaults listed below.  #FMOD_LOOP_OFF, #FMOD_2D, #FMOD_HARDWARE.
  #FMOD_LOOP_OFF = $1                      ; For non looping sounds. (default).  Overrides #FMOD_LOOP_NORMAL / #FMOD_LOOP_BIDI.
  #FMOD_LOOP_NORMAL = $2                   ; For forward looping sounds.
  #FMOD_LOOP_BIDI = $4                     ; For bidirectional looping sounds. (only works on software mixed static sounds).
  #FMOD_2D = $8                            ; Ignores any 3d processing. (default).
  #FMOD_3D = $10                           ; Makes the sound positionable in 3D.  Overrides #FMOD_2D.
  #FMOD_HARDWARE = $20                     ; Attempts to make sounds use hardware acceleration. (default).
  #FMOD_SOFTWARE = $40                     ; Makes sound reside in software.  Overrides #FMOD_HARDWARE.  Use this for FFT,  DSP, 2D multi speaker support and other software related features.
  #FMOD_CREATESTREAM = $80                 ; Decompress at runtime, streaming from the source provided (standard stream).  Overrides #FMOD_CREATESAMPLE.
  #FMOD_CREATESAMPLE = $100                ; Decompress at loadtime, decompressing or decoding whole file into memory as the target sample format. (standard sample).
  #FMOD_CREATECOMPRESSEDSAMPLE = $200      ; Load MP2, MP3, IMAADPCM or XMA into memory and leave it compressed.  During playback the FMOD software mixer will decode it in realtime as a 'compressed sample'.  Can only be used in combination with #FMOD_SOFTWARE.
  #FMOD_OPENUSER = $400                    ; Opens a user created static sample or stream. Use #FMOD_CREATESOUNDEXINFO to specify format and/or read callbacks.  If a user created 'sample' is created with no read callback, the sample will be empty.  Use #FMOD_Sound_Lock and #FMOD_Sound_Unlock to place sound data into the sound if this is the case.
  #FMOD_OPENMEMORY = $800                  ; "name_or_data" will be interpreted as a pointer to memory instead of filename for creating sounds.
  #FMOD_OPENRAW = $1000                    ; Will ignore file format and treat as raw pcm.  User may need to declare if data is #FMOD_SIGNED or #FMOD_UNSIGNED 
  #FMOD_OPENONLY = $2000                   ; Just open the file, dont prebuffer or read.  Good for fast opens for info, or when #FMOD_Sound_ReadData is to be used.
  #FMOD_ACCURATETIME = $4000               ; For #FMOD_System_CreateSound - for accurate #FMOD_Sound_GetLength / #FMOD_Channel_SetPosition on VBR MP3, AAC and MOD/S3M/XM/IT/MIDI files.  Scans file first, so takes longer to open. #FMOD_OPENONLY does not affect this.
  #FMOD_MPEGSEARCH = $8000                 ; For corrupted / bad MP3 files.  This will search all the way through the file until it hits a valid MPEG header.  Normally only searches for 4k.
  #FMOD_NONBLOCKING = $10000               ; For opening sounds asyncronously, return value from open function must be polled for when it is ready.
  #FMOD_UNIQUE = $20000                    ; Unique sound, can only be played one at a time 
  #FMOD_3D_HEADRELATIVE = $40000           ; Make the sound's position, velocity and orientation relative to the listener.
  #FMOD_3D_WORLDRELATIVE = $80000          ; Make the sound's position, velocity and orientation absolute (relative to the world). (DEFAULT)
  #FMOD_3D_LOGROLLOFF = $100000            ; This sound will follow the standard logarithmic rolloff model where mindistance = full volume, maxdistance = where sound stops attenuating, and rolloff is fixed according to the global rolloff factor.  (default)
  #FMOD_3D_LINEARROLLOFF = $200000         ; This sound will follow a linear rolloff model where mindistance = full volume, maxdistance = silence.
  #FMOD_3D_CUSTOMROLLOFF = $4000000        ; This sound will follow a rolloff model defined by #FMOD_Sound_Set3DCustomRolloff / #FMOD_Channel_Set3DCustomRolloff.
  #FMOD_CDDA_FORCEASPI = $400000           ; For CDDA sounds only - use ASPI instead of NTSCSI to access the specified CD/DVD device.
  #FMOD_CDDA_JITTERCORRECT = $800000       ; For CDDA sounds only - perform jitter correction. Jitter correction helps produce a more accurate CDDA stream at the cost of more CPU time.
  #FMOD_UNICODE = $1000000                 ; Filename is double-byte unicode.
  #FMOD_IGNORETAGS = $2000000              ; Skips id3v2/asf/etc tag checks when opening a sound, to reduce seek/read overhead when opening files (helps with CD performance).
  #FMOD_LOWMEM = $8000000                  ; Removes some features from samples to give a lower memory overhead, like #FMOD_Sound_GetName.
EndEnumeration

Structure FMOD_TAG
  type.l         ; [out] The type of this tag.
  datatype.l     ; [out] The type of data that this tag contains 
  name.l         ; [out] The name of this tag i.e. "TITLE", "ARTIST" etc.
  _data.l        ; [out] Pointer to the tag data - its format is determined by the datatype member 
  datalen.l      ; [out] Length of the data contained in this tag 
  udated.l       ; [out] True if this tag has been updated since last being accessed with Sound::getTag 
EndStructure

Structure FMOD_CDTOC
  numtracks.l    ; [out] The number of tracks on the CD 
  min.l[100]     ; [out] The start offset of each track in minutes 
  sec.l[100]     ; [out] The start offset of each track in seconds 
  frame.l[100]   ; [out] The start offset of each track in frames 
EndStructure

Structure FMOD_CREATESOUNDEXINFO
  cbSize.l                          ; [in] Size of this structure.  This is used so the structure can be expanded in the future and still work on older versions of FMOD Ex.
  Length.l                          ; [in] Optional. Specify 0 to ignore. Size in bytes of file to load, or sound to create (in this case only if FMOD_OPENUSER is used).  Required if loading from memory.  If 0 is specified, then it will use the size of the file (unless loading from memory then an error will be returned).
  fileoffset.l                      ; [in] Optional. Specify 0 to ignore. Offset from start of the file to start loading from.  This is useful for loading files from inside big data files.
  Numchannels.l                     ; [in] Optional. Specify 0 to ignore. Number of channels in a sound specified only if FMOD_OPENUSER is used.
  defaultfrequency.l                ; [in] Optional. Specify 0 to ignore. Default frequency of sound in a sound specified only if FMOD_OPENUSER is used.  Other formats use the frequency determined by the file format.
  Format.l ; [in] Optional. Specify 0 or FMOD_SOUND_FORMAT_NONE to ignore. Format of the sound specified only if FMOD_OPENUSER is used.  Other formats use the format determined by the file format.
  decodebuffersize.l                ; [in] Optional. Specify 0 to ignore. For streams.  This determines the size of the double buffer (in PCM samples) that a stream uses.  Use this for user created streams if you want to determine the size of the callback buffer passed to you.  Specify 0 to use FMOD's default size which is currently equivalent to 400ms of the sound format created/loaded.
  initialsubsound.l                 ; [in] Optional. Specify 0 to ignore. In a multi-sample file format such as .FSB/.DLS/.SF2, specify the initial subsound to seek to, only if FMOD_CREATESTREAM is used.
  Numsubsounds.l                    ; [in] Optional. Specify 0 to ignore or have no subsounds.  In a user created multi-sample sound, specify the number of subsounds within the sound that are accessable with Sound::getSubSound.
  inclusionlist.l                   ; [in] Optional. Specify 0 to ignore. In a multi-sample format such as .FSB/.DLS/.SF2 it may be desirable to specify only a subset of sounds to be loaded out of the whole file.  This is an array of subsound indicies to load into memory when created.
  inclusionlistnum.l                ; [in] Optional. Specify 0 to ignore. This is the number of integers contained within the inclusionlist array.
  pcmreadcallback.l                 ; [in] Optional. Specify 0 to ignore. Callback to 'piggyback' on FMOD's read functions and accept or even write PCM data while FMOD is opening the sound.  Used for user sounds created with FMOD_OPENUSER or for capturing decoded data as FMOD reads it.
  pcmsetposcallback.l               ; [in] Optional. Specify 0 to ignore. Callback for when the user calls a seeking function such as Channel::setTime or Channel::setPosition within a multi-sample sound, and for when it is opened.
  nonblockcallback.l                ; [in] Optional. Specify 0 to ignore. Callback for successful completion, or error while loading a sound that used the FMOD_NONBLOCKING flag.
  dlsname.s                         ; [in] Optional. Specify 0 to ignore. Filename for a DLS or SF2 sample set when loading a MIDI file.   If not specified, on windows it will attempt to open /windows/system32/drivers/gm.dls, otherwise the MIDI will fail to open.
  encryptionkey.s                   ; [in] Optional. Specify 0 to ignore. Key for encrypted FSB file.  Without this key an encrypted FSB file will not load.
  maxpolyphony.l                    ; [in] Optional. Specify 0 to ingore. For sequenced formats with dynamic channel allocation such as .MID and .IT, this specifies the maximum voice count allowed while playing.  .IT defaults to 64.  .MID defaults to 32.
  userdata.l                        ; [in] Optional. Specify 0 to ignore. This is user data to be attached to the sound during creation.  Access via Sound::getUserData. 
  suggestedsoundtype.l              ; [in] Optional. Specify 0 Or FMOD_SOUND_TYPE_UNKNOWN To ignore.  Instead of scanning all codec types, use this To speed up loading by making it jump straight To this codec.
  useropen.l                        ; [in] Optional. Specify 0 to ignore. Callback for opening this file.
  userclose.l                       ; [in] Optional. Specify 0 to ignore. Callback for closing this file.
  userread.l                        ; [in] Optional. Specify 0 to ignore. Callback for reading from this file.
  userseek.l                        ; [in] Optional. Specify 0 to ignore. Callback for seeking within this file.
EndStructure

#FMOD_CREATESOUNDEXINFO_SIZE  = 92 ;sizeof(#FMOD_CREATESOUNDEXINFO)

Enumeration ; FMOD_CHANNELINDEX
  #FMOD_CHANNEL_FREE = -1     ; For a channel index, FMOD chooses a free voice using the priority system.
  #FMOD_CHANNEL_REUSE = -2    ; For a channel index, re-use the channel handle that was passed in.
EndEnumeration


Enumeration ; FMOD_DSP_TYPE
  #FMOD_DSP_TYPE_UNKNOWN            ; This unit was created via a non FMOD plugin so has an unknown purpose. 
  #FMOD_DSP_TYPE_MIXER              ; This unit does nothing but take inputs and mix them together then feed the result to the soundcard unit. 
  #FMOD_DSP_TYPE_OSCILLATOR         ; This unit generates sine/square/saw/triangle or noise tones. 
  #FMOD_DSP_TYPE_LOWPASS            ; This unit filters sound using a high quality, resonant lowpass filter algorithm but consumes more CPU time. 
  #FMOD_DSP_TYPE_ITLOWPASS          ; This unit filters sound using a resonant lowpass filter algorithm that is used in Impulse Tracker, but with limited cutoff range (0 to 8060hz). 
  #FMOD_DSP_TYPE_HIGHPASS           ; This unit filters sound using a resonant highpass filter algorithm. 
  #FMOD_DSP_TYPE_ECHO               ; This unit produces an echo on the sound and fades out at the desired rate. 
  #FMOD_DSP_TYPE_FLANGE             ; This unit produces a flange effect on the sound. 
  #FMOD_DSP_TYPE_DISTORTION         ; This unit distorts the sound. 
  #FMOD_DSP_TYPE_NORMALIZE          ; This unit normalizes or amplifies the sound to a certain level. 
  #FMOD_DSP_TYPE_PARAMEQ            ; This unit attenuates or amplifies a selected frequency range. 
  #FMOD_DSP_TYPE_PITCHSHIFT         ; This unit bends the pitch of a sound without changing the speed of playback. 
  #FMOD_DSP_TYPE_CHORUS             ; This unit produces a chorus effect on the sound. 
  #FMOD_DSP_TYPE_REVERB             ; This unit produces a reverb effect on the sound. 
  #FMOD_DSP_TYPE_VSTPLUGIN          ; This unit allows the use of Steinberg VST plugins 
  #FMOD_DSP_TYPE_WINAMPPLUGIN       ; This unit allows the use of Nullsoft Winamp plugins 
  #FMOD_DSP_TYPE_ITECHO             ; This unit produces an echo on the sound and fades out at the desired rate as is used in Impulse Tracker. 
  #FMOD_DSP_TYPE_COMPRESSOR         ; This unit implements dynamic compression (linked multichannel, wideband) 
  #FMOD_DSP_TYPE_SFXREVERB          ; This unit implements SFX reverb 
  #FMOD_DSP_TYPE_LOWPASS_SIMPLE     ; This unit filters sound using a simple lowpass with no resonance, but has flexible cutoff and is fast. 
EndEnumeration

Enumeration ; FMOD_DSP_OSCILLATOR
  #FMOD_DSP_OSCILLATOR_TYPE    ; Waveform type.  0 = sine.  1 = square. 2 = sawup. 3 = sawdown. 4 = triangle. 5 = noise.  
  #FMOD_DSP_OSCILLATOR_RATE    ; Frequency of the sinewave in hz.  1.0 to 22000.0.  Default = 220.0. 
EndEnumeration

Enumeration ; FMOD_DSP_PARAMEQ
  #FMOD_DSP_PARAMEQ_CENTER      ; Frequency center.  20.0 to 22000.0.  Default = 8000.0. 
  #FMOD_DSP_PARAMEQ_BANDWIDTH   ; Octave range around the center frequency to filter.  0.2 to 5.0.  Default = 1.0. 
  #FMOD_DSP_PARAMEQ_GAIN        ; Frequency Gain.  0.05 to 3.0.  Default = 1.0.  
EndEnumeration

Enumeration ; FMOD_DSP_REVERB
  #FMOD_DSP_REVERB_ROOMSIZE  ; Roomsize. 0.0 to 1.0.  Default = 0.5 
  #FMOD_DSP_REVERB_DAMP      ; Damp.     0.0 to 1.0.  Default = 0.5 
  #FMOD_DSP_REVERB_WETMIX    ; Wet mix.  0.0 to 1.0.  Default = 0.33 
  #FMOD_DSP_REVERB_DRYMIX    ; Dry mix.  0.0 to 1.0.  Default = 0.0 
  #FMOD_DSP_REVERB_WIDTH     ; Width.    0.0 to 1.0.  Default = 1.0 
  #FMOD_DSP_REVERB_MODE      ; Mode.     0 (normal), 1 (freeze).  Default = 0 
EndEnumeration

Enumeration ; FMOD_DSP_PITCHSHIFT
  #FMOD_DSP_PITCHSHIFT_PITCH        ; Pitch value.  0.5 to 2.0.  Default = 1.0. 0.5 = one octave down, 2.0 = one octave up.  1.0 does not change the pitch. 
  #FMOD_DSP_PITCHSHIFT_FFTSIZE      ; FFT window size.  256, 512, 1024, 2048, 4096.  Default = 1024.  Increase this to reduce 'smearing'.  This effect is a warbling sound similar to when an mp3 is encoded at very low bitrates. 
  #FMOD_DSP_PITCHSHIFT_OVERLAP      ; Window overlap.  1 to 32.  Default = 4.  Increase this to reduce 'tremolo' effect.  Increasing it by a factor of 2 doubles the CPU usage. 
  #FMOD_DSP_PITCHSHIFT_MAXCHANNELS  ; Maximum channels supported.  0 to 16.  0 = same as fmod's default output polyphony, 1 = mono, 2 = stereo etc.  See remarks for more.  Default = 0.  It is suggested to leave at 0! 
EndEnumeration

Enumeration ; FMOD_DSP_SFXREVERB
  #FMOD_DSP_SFXREVERB_DRYLEVEL             ; Dry Level      : Mix level of dry signal in output in mB.  Ranges from -10000.0 to 0.0.  Default is 0.0. 
  #FMOD_DSP_SFXREVERB_ROOM                 ; Room           : Room effect level at low frequencies in mB.  Ranges from -10000.0 to 0.0.  Default is 0.0. 
  #FMOD_DSP_SFXREVERB_ROOMHF               ; Room HF        : Room effect high-frequency level re. low frequency level in mB.  Ranges from -10000.0 to 0.0.  Default is 0.0. 
  #FMOD_DSP_SFXREVERB_ROOMROLLOFFFACTOR    ; Room Rolloff   : Like DS3D flRolloffFactor but for room effect.  Ranges from 0.0 to 10.0. Default is 10.0 
  #FMOD_DSP_SFXREVERB_DECAYTIME            ; Decay Time     : Reverberation decay time at low-frequencies in seconds.  Ranges from 0.1 to 20.0. Default is 1.0. 
  #FMOD_DSP_SFXREVERB_DECAYHFRATIO         ; Decay HF Ratio : High-frequency to low-frequency decay time ratio.  Ranges from 0.1 to 2.0. Default is 0.5. 
  #FMOD_DSP_SFXREVERB_REFLECTIONSLEVEL     ; Reflections    : Early reflections level relative to room effect in mB.  Ranges from -10000.0 to 1000.0.  Default is -10000.0. 
  #FMOD_DSP_SFXREVERB_REFLECTIONSDELAY     ; Reflect Delay  : Delay time of first reflection in seconds.  Ranges from 0.0 to 0.3.  Default is 0.02. 
  #FMOD_DSP_SFXREVERB_REVERBLEVEL          ; Reverb         : Late reverberation level relative to room effect in mB.  Ranges from -10000.0 to 2000.0.  Default is 0.0. 
  #FMOD_DSP_SFXREVERB_REVERBDELAY          ; Reverb Delay   : Late reverberation delay time relative to first reflection in seconds.  Ranges from 0.0 to 0.1.  Default is 0.04. 
  #FMOD_DSP_SFXREVERB_DIFFUSION            ; Diffusion      : Reverberation diffusion (echo density) in percent.  Ranges from 0.0 to 100.0.  Default is 100.0. 
  #FMOD_DSP_SFXREVERB_DENSITY              ; Density        : Reverberation density (modal density) in percent.  Ranges from 0.0 to 100.0.  Default is 100.0. 
  #FMOD_DSP_SFXREVERB_HFREFERENCE          ; HF Reference   : Reference high frequency in Hz.  Ranges from 20.0 to 20000.0. Default is 5000.0. 
EndEnumeration

Enumeration ; FMOD_DSP_ECHO
  #FMOD_DSP_ECHO_DELAY        ; Echo delay in ms.  10  to 5000.  Default = 500. 
  #FMOD_DSP_ECHO_DECAYRATIO   ; Echo decay per delay.  0 to 1.  1.0 = No decay, 0.0 = total decay.  Default = 0.5. 
  #FMOD_DSP_ECHO_MAXCHANNELS  ; Maximum channels supported.  0 to 16.  0 = same as fmod's default output polyphony, 1 = mono, 2 = stereo etc.  See remarks for more.  Default = 0.  It is suggested to leave at 0! 
  #FMOD_DSP_ECHO_DRYMIX       ; Volume of original signal to pass to output.  0.0 to 1.0. Default = 1.0. 
  #FMOD_DSP_ECHO_WETMIX       ; Volume of echo signal to pass to output.  0.0 to 1.0. Default = 1.0. 
EndEnumeration
;- ### Main part
CompilerIf #PB_Compiler_Processor = #PB_Processor_x86
  fmodLib = OpenLibrary(#PB_Any, "fmodex.dll")
CompilerElse
  fmodLib = OpenLibrary(#PB_Any, "fmodex64.dll")
CompilerEndIf

If fmodLib
  ;- FMOD_System_Init_
  Prototype.l FMOD_System_Init_Prototype (system.l, Maxchannels.l, flags.l, Extradriverdata.l);system.l, Maxchannels.l, flags.l, Extradriverdata.l
  Global FMOD_System_Init.FMOD_System_Init_Prototype
  FMOD_System_Init = GetFunction(fmodLib, "FMOD_System_Init") 
  
  ;- FMOD_System_Create
  Prototype.l FMOD_System_Create_Prototype(*system)
  Global FMOD_System_Create.FMOD_System_Create_Prototype
  FMOD_System_Create = GetFunction(fmodLib, "FMOD_System_Create")
  
  ;- FMOD_System_Release
  Prototype.l FMOD_System_Release_Prototype(system.l)
  Global FMOD_System_Release.FMOD_System_Release_Prototype
  FMOD_System_Release = GetFunction(fmodLib, "FMOD_System_Release")
 
    ;- FMOD_System_CreateDSPByType_
  Prototype.l FMOD_System_CreateDSPByType_Prototype (system.l, dsptype.l, *Dsp)
  Global FMOD_System_CreateDSPByType.FMOD_System_CreateDSPByType_Prototype
  FMOD_System_CreateDSPByType = GetFunction(fmodLib, "FMOD_System_CreateDSPByType")
  
    ;- FMOD_System_AddDSP_
  Prototype.l FMOD_System_AddDSP_Prototype (system.l, Dsp.l,Connection.l)
  Global FMOD_System_AddDSP.FMOD_System_AddDSP_Prototype
  FMOD_System_AddDSP = GetFunction(fmodLib, "FMOD_System_AddDSP")
  
  ;- FMOD_System_Close_
  Prototype.l FMOD_System_Close_Prototype (system.l)
  Global FMOD_System_Close.FMOD_System_Close_Prototype
  FMOD_System_Close = GetFunction(fmodLib, "FMOD_System_Close")

;- FMOD_System_PlaySound_
  Prototype.l FMOD_System_PlaySound_Prototype (system.l, channelid.l, sound.l, paused.l, *channel)
  Global FMOD_System_PlaySound.FMOD_System_PlaySound_Prototype
  FMOD_System_PlaySound = GetFunction(fmodLib, "FMOD_System_PlaySound")
  
    ;- FMOD_System_PlayDSP_
  Prototype.l FMOD_System_PlayDSP_Prototype (system.l, channelid.l, Dsp.l, paused.l, *channel)
  Global FMOD_System_PlayDSP.FMOD_System_PlayDSP_Prototype
  FMOD_System_PlayDSP = GetFunction(fmodLib, "FMOD_System_PlayDSP")

  ;- FMOD_System_GetChannel_
  Prototype.l FMOD_System_GetChannel_Prototype (system.l, channelid.l, *channel)
  Global FMOD_System_GetChannel.FMOD_System_GetChannel_Prototype
  FMOD_System_GetChannel = GetFunction(fmodLib, "FMOD_System_GetChannel")
  
    ;- FMOD_System_SetReverbProperties_
  Prototype.l FMOD_System_SetReverbProperties_Prototype (system.l, *Prop)
  Global FMOD_System_SetReverbProperties.FMOD_System_SetReverbProperties_Prototype
  FMOD_System_SetReverbProperties = GetFunction(fmodLib, "FMOD_System_SetReverbProperties")
  
      ;- FMOD_System_CreateReverb_
  Prototype.l FMOD_System_CreateReverb_Prototype (system.l, *reverb)
  Global FMOD_System_CreateReverb.FMOD_System_CreateReverb_Prototype
  FMOD_System_CreateReverb = GetFunction(fmodLib, "FMOD_System_CreateReverb")
  
  ;- FMOD_Sound_Release_
  Prototype.l FMOD_Sound_Release_Prototype (sound.l)
  Global FMOD_Sound_Release.FMOD_Sound_Release_Prototype
  FMOD_Sound_Release = GetFunction(fmodLib, "FMOD_Sound_Release")
  
;- FMOD_Sound_GetName_
  Prototype.l FMOD_Sound_GetName_Prototype (sound.l, *name, Namelen.l)
  Global FMOD_Sound_GetName.FMOD_Sound_GetName_Prototype
  FMOD_Sound_GetName = GetFunction(fmodLib, "FMOD_Sound_GetName")
  
  ;- FMOD_Sound_GetLength_
  Prototype.l FMOD_Sound_GetLength_Prototype (sound.l, *Length, Lengthtype.l)
  Global FMOD_Sound_GetLength.FMOD_Sound_GetLength_Prototype
  FMOD_Sound_GetLength = GetFunction(fmodLib, "FMOD_Sound_GetLength")
  
  ;- FMOD_Sound_GetFormat_
  Prototype.l FMOD_Sound_GetFormat_Prototype (sound.l, *Soundtype, *Format, *Channels, *Bits)
  Global FMOD_Sound_GetFormat.FMOD_Sound_GetFormat_Prototype
  FMOD_Sound_GetFormat = GetFunction(fmodLib, "FMOD_Sound_GetFormat")
  
  ;- FMOD_Channel_Stop_
  Prototype.l FMOD_Channel_Stop_Prototype (channel.l)
  Global FMOD_Channel_Stop.FMOD_Channel_Stop_Prototype
  FMOD_Channel_Stop = GetFunction(fmodLib, "FMOD_Channel_Stop")
  
  ;- FMOD_System_CreateStream_
  Prototype.l FMOD_System_CreateStream_Prototype (system.l, Name_or_data.l, Mode.l, *exinfo, *Sound)
  Global FMOD_System_CreateStream.FMOD_System_CreateStream_Prototype
  FMOD_System_CreateStream = GetFunction(fmodLib, "FMOD_System_CreateStream")
  
  ;- FMOD_Channel_SetPaused_
  Prototype.l FMOD_Channel_SetPaused_Prototype (channel.l, paused.l)
  Global FMOD_Channel_SetPaused.FMOD_Channel_SetPaused_Prototype
  FMOD_Channel_SetPaused = GetFunction(fmodLib, "FMOD_Channel_SetPaused")
  
  ;- FMOD_Channel_GetPaused_
  Prototype.l FMOD_Channel_GetPaused_Prototype (channel.l, *paused)
  Global FMOD_Channel_GetPaused.FMOD_Channel_GetPaused_Prototype
  FMOD_Channel_GetPaused = GetFunction(fmodLib, "FMOD_Channel_GetPaused")
  
  ;- FMOD_Channel_SetVolume
  Prototype.l FMOD_Channel_SetVolume_Prototype(channel.l, Volume.f)
  Global FMOD_Channel_SetVolume.FMOD_Channel_SetVolume_Prototype
  FMOD_Channel_SetVolume = GetFunction(fmodLib, "FMOD_Channel_SetVolume")
  
  ;- FMOD_Channel_GetVolume
  Prototype.l FMOD_Channel_GetVolume_Prototype(channel.l, *Volume)
  Global FMOD_Channel_GetVolume.FMOD_Channel_GetVolume_Prototype
  FMOD_Channel_GetVolume = GetFunction(fmodLib, "FMOD_Channel_GetVolume")
  
  ;- FMOD_Channel_GetPosition_
  Prototype.l FMOD_Channel_GetPosition_Prototype (channel.l, *Position, Postype.l)
  Global FMOD_Channel_GetPosition.FMOD_Channel_GetPosition_Prototype
  FMOD_Channel_GetPosition = GetFunction(fmodLib, "FMOD_Channel_GetPosition")
  
  ;- FMOD_Channel_SetPosition_
  Prototype.l FMOD_Channel_SetPosition_Prototype (channel.l, Position.l, Postype.l)
  Global FMOD_Channel_SetPosition.FMOD_Channel_SetPosition_Prototype
  FMOD_Channel_SetPosition = GetFunction(fmodLib, "FMOD_Channel_SetPosition")
  
    ;- FMOD_Channel_SetFrequency_
  Prototype.l FMOD_Channel_SetFrequency_Prototype (channel.l, Frequency.f)
  Global FMOD_Channel_SetFrequency.FMOD_Channel_SetFrequency_Prototype
  FMOD_Channel_SetFrequency = GetFunction(fmodLib, "FMOD_Channel_SetFrequency")
  
  ;- FMOD_Channel_GetFrequency_
  Prototype.l FMOD_Channel_GetFrequency_Prototype (channel.l, *Frequency)
  Global FMOD_Channel_GetFrequency.FMOD_Channel_GetFrequency_Prototype
  FMOD_Channel_GetFrequency = GetFunction(fmodLib, "FMOD_Channel_GetFrequency")
  
  ;- FMOD_Channel_GetSpectrum_
  Prototype.l FMOD_Channel_GetSpectrum_Prototype (channel.l, *Spectrumarray, Numvalues.l, Channeloffset.l, Windowtype.l)
  Global FMOD_Channel_GetSpectrum.FMOD_Channel_GetSpectrum_Prototype
  FMOD_Channel_GetSpectrum = GetFunction(fmodLib, "FMOD_Channel_GetSpectrum")
  
  ;- FMOD_Channel_GetWaveData_
  Prototype.l FMOD_Channel_GetWaveData_Prototype (channel.l, *Wavearray, Numvalues.l, Channeloffset.l)
  Global FMOD_Channel_GetWaveData.FMOD_Channel_GetWaveData_Prototype
  FMOD_Channel_GetWaveData = GetFunction(fmodLib, "FMOD_Channel_GetWaveData")
  
    ;- FMOD_Channel_AddDSP_
  Prototype.l FMOD_Channel_AddDSP_Prototype (channel.l, Dsp.l, Connection.l)
  Global FMOD_Channel_AddDSP.FMOD_Channel_AddDSP_Prototype
  FMOD_Channel_AddDSP = GetFunction(fmodLib, "FMOD_Channel_AddDSP")
  
    ;- FMOD_DSP_SetParameter_
  Prototype.l FMOD_DSP_SetParameter_Prototype (Dsp.l, Index.l, Value.f)
  Global FMOD_DSP_SetParameter.FMOD_DSP_SetParameter_Prototype
  FMOD_DSP_SetParameter = GetFunction(fmodLib, "FMOD_DSP_SetParameter")
  
    ;- FMOD_DSP_SetBypass_
  Prototype.l FMOD_DSP_SetBypass_Prototype (Dsp.l, Bypass.l)
  Global FMOD_DSP_SetBypass.FMOD_DSP_SetBypass_Prototype
  FMOD_DSP_SetBypass = GetFunction(fmodLib, "FMOD_DSP_SetBypass")
EndIf

; IDE Options = PureBasic 5.42 LTS (Windows - x64)
; CursorPosition = 217
; FirstLine = 173
; Folding = -
; EPB